#
# spec file for package kanshi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kanshi
Version:        1.5.0
Release:        1.2
Summary:        Dynamic display configuration
License:        MIT
Group:          System/GUI/Other
URL:            https://git.sr.ht/~emersion/kanshi
Source:         %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  scdoc
BuildRequires:  pkgconfig(wayland-client)

%description
kanshi allows you to define output profiles that are automatically enabled
and disabled on hotplug.

%prep
%setup -q -n kanshi-v%{version}

%build
# Disabled because libvarlink is not available in Factory
%meson \
  -Dipc=disabled
%meson_build

%install
%meson_install

%files
%{_bindir}/kanshi
%{_mandir}/man?/%{name}*

%changelog
* Wed Jan 17 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to v.1.5.0:
  * Bind to output manager v3 if v4 isn't supported
  * Wait for output configuration events when handling IPC calls
  * Fix missing IPC reply on config reload error
  * Add support for custom modes
    Implements: https://todo.sr.ht/~emersion/kanshi/80
* Fri Jun 30 2023 llyyr <llyyr.public@gmail.com>
- Update to v.1.4.0:
  * Add support for adaptive sync
  * Add kanshictl switch
  * Keep current profile if it still matches
  * Add --listen-fd
  * manpage improvements
* Thu Mar 16 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to v1.3.1:
  * Pick lowest delta when fuzzy matching refreshes
  * Fall back to "Unknown" when make/model/serial is unset
* Tue Aug 30 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to v1.3.0:
  * This release adds an IPC interface with a kanshictl utility,
    improves make-model-serial matching, and fixes a handful of bugs.
    libvarlink is a new optional dependency.
  * Support output-management version 3 release requests
  * Improve the make-model-serial matching of outputs
  * Upgrade wlr-output-management-unstable-v1.xml to version 2
* Sun Jun 26 2022 Tomasz Hołubowicz <alternateved@pm.me>
- Update to v1.2.0
  * parser: print errno when failing to open the config file
  * parser: explicitly initialize key (kanshi_output_field) to 0
  * [man 5] Add blockquotes to ensure line break
  * Properly reap children to avoid zombies
  * Add missing header after 5a30abdf0b3b
  * Accept user-specified config path
  * Add 'include' directive to read additional configs
  * Add the 'profile' directive in kanshi(5) examples
  * readme: move to Libera Chat
  * readme: switch to new profile syntax
  * build: bump version to 1.2.0
  * parser: use abort() instead of assert(0)
* Fri Apr 17 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Update to v1.1.0
  * Add support for comments in configuration file
  * Allow names to distinguish configuration
  * Add `exec` to execute commands when a configuration is matched
  * Be tolerant to matching refresh rates that are a few points off.
  * Select highest refresh rate for selected mode when none is specified.
  * Fix typo in man page
  * Use correct formatting for variable in man page
  * Specify correct version in meson.build
  * Fix parser_next_token return value
  * Require profiles with a name to have a profile directive
* Thu Sep  5 2019 Michael Aquilina <michaelaquilina@gmail.com>
- First kanshi release
